@@ -2,8 +2,9 @@ from typing import Optional, List
 
 from pydalle.functional.api.request.labs import login_request, get_tasks_request, create_task_request, \
     get_task_request, download_generation_request, save_generations_request, share_generation_request, \
-    flag_generation_request
-from pydalle.functional.api.response.labs import TaskList, TaskType, Task, Generation, Collection, Login, UserFlag
+    flag_generation_request, get_credit_summary_request
+from pydalle.functional.api.response.labs import TaskList, TaskType, Task, Generation, Collection, Login, UserFlag, \
+    BillingInfo
 from pydalle.functional.types import HttpFlow, FlowError, JsonDict
 from pydalle.functional.utils import send_from, try_json
 
@@ -174,3 +175,16 @@ def save_generations_flow(bearer_token: str, generation_ids: List[str],
         return Collection.from_dict(j)
     except Exception as e:
         raise FlowError("Failed to parse response", r) from e
+
+
+def get_credit_summary_flow(bearer_token: str) -> HttpFlow[BillingInfo]:
+    r = yield get_credit_summary_request(bearer_token)
+    while r.status_code == 504:
+        r = yield get_credit_summary_request(bearer_token, sleep=DEFAULT_INTERVAL)
+    if r.status_code != 200:
+        raise FlowError("Failed to get credit summary", r)
+    j = try_json(r, status_code=200)
+    try:
+        return BillingInfo.from_dict(j)
+    except Exception as e:
+        raise FlowError("Failed to parse response", r) from e
