@@ -13,6 +13,8 @@ OPENAI_LABS_TASKS_URL = f"{OPENAI_LABS_API_URL}/tasks"
 OPENAI_LABS_TASK_URL_TEMPLATE = f"{OPENAI_LABS_TASKS_URL}/%s"
 OPENAI_LABS_GENERATION_URL = "https://labs.openai.com/api/labs/generations"
 OPENAI_LABS_GENERATION_DOWNLOAD_URL_TEMPLATE = f"{OPENAI_LABS_GENERATION_URL}/%s/download"
+OPENAI_LABS_BILLING_URL = f"{OPENAI_LABS_API_URL}/billing"
+OPENAI_LABS_BILLING_CREDIT_SUMMARY_URL = f"{OPENAI_LABS_BILLING_URL}/credit_summary"
 OPENAI_LABS_GENERATION_SHARE_URL_TEMPLATE = f"{OPENAI_LABS_GENERATION_URL}/%s/share"
 OPENAI_LABS_GENERATION_FLAG_URL_TEMPLATE = f"{OPENAI_LABS_GENERATION_URL}/%s/flags"
 OPENAI_LABS_COLLECTION_URL = f"{OPENAI_LABS_API_URL}/collections"
